==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/ShiftItem.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.time.OffsetDateTime;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

import odata.msgraph.client.beta.enums.ScheduleEntityTheme;
import odata.msgraph.client.beta.schema.SchemaInfo;

@JsonPropertyOrder({
    "@odata.type", 
    "displayName", 
    "notes", 
    "activities"})
@JsonInclude(Include.NON_NULL)
public class ShiftItem extends ScheduleEntity implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("displayName")
    protected String displayName;

    @JsonProperty("notes")
    protected String notes;

    @JsonProperty("activities")
    protected List<ShiftActivity> activities;

    @JsonProperty("activities@nextLink")
    protected String activitiesNextLink;

    protected ShiftItem() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.shiftItem";
    }

    @Property(name="displayName")
    @JsonIgnore
    public Optional<String> getDisplayName() {
        return Optional.ofNullable(displayName);
    }

    public ShiftItem withDisplayName(String displayName) {
        ShiftItem _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.shiftItem");
        _x.displayName = displayName;
        return _x;
    }

    @Property(name="notes")
    @JsonIgnore
    public Optional<String> getNotes() {
        return Optional.ofNullable(notes);
    }

    public ShiftItem withNotes(String notes) {
        ShiftItem _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.shiftItem");
        _x.notes = notes;
        return _x;
    }

    @Property(name="activities")
    @JsonIgnore
    public CollectionPage<ShiftActivity> getActivities() {
        return new CollectionPage<ShiftActivity>(contextPath, ShiftActivity.class, activities, Optional.ofNullable(activitiesNextLink), SchemaInfo.INSTANCE, Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="activities")
    @JsonIgnore
    public CollectionPage<ShiftActivity> getActivities(HttpRequestOptions options) {
        return new CollectionPage<ShiftActivity>(contextPath, ShiftActivity.class, activities, Optional.ofNullable(activitiesNextLink), SchemaInfo.INSTANCE, Collections.emptyList(), options);
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderShiftItem() {
        return new Builder();
    }

    public static final class Builder {
        private OffsetDateTime startDateTime;
        private OffsetDateTime endDateTime;
        private ScheduleEntityTheme theme;
        private String displayName;
        private String notes;
        private List<ShiftActivity> activities;
        private String activitiesNextLink;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder startDateTime(OffsetDateTime startDateTime) {
            this.startDateTime = startDateTime;
            this.changedFields = changedFields.add("startDateTime");
            return this;
        }

        public Builder endDateTime(OffsetDateTime endDateTime) {
            this.endDateTime = endDateTime;
            this.changedFields = changedFields.add("endDateTime");
            return this;
        }

        public Builder theme(ScheduleEntityTheme theme) {
            this.theme = theme;
            this.changedFields = changedFields.add("theme");
            return this;
        }

        public Builder displayName(String displayName) {
            this.displayName = displayName;
            this.changedFields = changedFields.add("displayName");
            return this;
        }

        public Builder notes(String notes) {
            this.notes = notes;
            this.changedFields = changedFields.add("notes");
            return this;
        }

        public Builder activities(List<ShiftActivity> activities) {
            this.activities = activities;
            this.changedFields = changedFields.add("activities");
            return this;
        }

        public Builder activities(ShiftActivity... activities) {
            return activities(Arrays.asList(activities));
        }

        public Builder activitiesNextLink(String activitiesNextLink) {
            this.activitiesNextLink = activitiesNextLink;
            this.changedFields = changedFields.add("activities");
            return this;
        }

        public ShiftItem build() {
            ShiftItem _x = new ShiftItem();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.shiftItem";
            _x.startDateTime = startDateTime;
            _x.endDateTime = endDateTime;
            _x.theme = theme;
            _x.displayName = displayName;
            _x.notes = notes;
            _x.activities = activities;
            _x.activitiesNextLink = activitiesNextLink;
            return _x;
        }
    }

    private ShiftItem _copy() {
        ShiftItem _x = new ShiftItem();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.startDateTime = startDateTime;
        _x.endDateTime = endDateTime;
        _x.theme = theme;
        _x.displayName = displayName;
        _x.notes = notes;
        _x.activities = activities;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ShiftItem[");
        b.append("startDateTime=");
        b.append(this.startDateTime);
        b.append(", ");
        b.append("endDateTime=");
        b.append(this.endDateTime);
        b.append(", ");
        b.append("theme=");
        b.append(this.theme);
        b.append(", ");
        b.append("displayName=");
        b.append(this.displayName);
        b.append(", ");
        b.append("notes=");
        b.append(this.notes);
        b.append(", ");
        b.append("activities=");
        b.append(this.activities);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/complex/ShiftItem.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.time.OffsetDateTime;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

import odata.msgraph.client.beta.enums.ScheduleEntityTheme;

@JsonPropertyOrder({
    "@odata.type", 
    "activities", 
    "displayName", 
    "notes"})
@JsonInclude(Include.NON_NULL)
public class ShiftItem extends ScheduleEntity implements ODataType {

    @JsonProperty("activities")
    protected List<ShiftActivity> activities;

    @JsonProperty("activities@nextLink")
    protected String activitiesNextLink;

    @JsonProperty("displayName")
    protected String displayName;

    @JsonProperty("notes")
    protected String notes;

    protected ShiftItem() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.shiftItem";
    }

    @Property(name="activities")
    @JsonIgnore
    public CollectionPage<ShiftActivity> getActivities() {
        return new CollectionPage<ShiftActivity>(contextPath, ShiftActivity.class, this.activities, Optional.ofNullable(activitiesNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="activities")
    @JsonIgnore
    public CollectionPage<ShiftActivity> getActivities(HttpRequestOptions options) {
        return new CollectionPage<ShiftActivity>(contextPath, ShiftActivity.class, this.activities, Optional.ofNullable(activitiesNextLink), Collections.emptyList(), options);
    }

    @Property(name="displayName")
    @JsonIgnore
    public Optional<String> getDisplayName() {
        return Optional.ofNullable(displayName);
    }

    public ShiftItem withDisplayName(String displayName) {
        ShiftItem _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.shiftItem");
        _x.displayName = displayName;
        return _x;
    }

    @Property(name="notes")
    @JsonIgnore
    public Optional<String> getNotes() {
        return Optional.ofNullable(notes);
    }

    public ShiftItem withNotes(String notes) {
        ShiftItem _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.shiftItem");
        _x.notes = notes;
        return _x;
    }

    public ShiftItem withUnmappedField(String name, Object value) {
        ShiftItem _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderShiftItem() {
        return new Builder();
    }

    public static final class Builder {
        private OffsetDateTime endDateTime;
        private OffsetDateTime startDateTime;
        private ScheduleEntityTheme theme;
        private List<ShiftActivity> activities;
        private String activitiesNextLink;
        private String displayName;
        private String notes;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder endDateTime(OffsetDateTime endDateTime) {
            this.endDateTime = endDateTime;
            this.changedFields = changedFields.add("endDateTime");
            return this;
        }

        public Builder startDateTime(OffsetDateTime startDateTime) {
            this.startDateTime = startDateTime;
            this.changedFields = changedFields.add("startDateTime");
            return this;
        }

        public Builder theme(ScheduleEntityTheme theme) {
            this.theme = theme;
            this.changedFields = changedFields.add("theme");
            return this;
        }

        public Builder activities(List<ShiftActivity> activities) {
            this.activities = activities;
            this.changedFields = changedFields.add("activities");
            return this;
        }

        public Builder activities(ShiftActivity... activities) {
            return activities(Arrays.asList(activities));
        }

        public Builder activitiesNextLink(String activitiesNextLink) {
            this.activitiesNextLink = activitiesNextLink;
            this.changedFields = changedFields.add("activities");
            return this;
        }

        public Builder displayName(String displayName) {
            this.displayName = displayName;
            this.changedFields = changedFields.add("displayName");
            return this;
        }

        public Builder notes(String notes) {
            this.notes = notes;
            this.changedFields = changedFields.add("notes");
            return this;
        }

        public ShiftItem build() {
            ShiftItem _x = new ShiftItem();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.shiftItem";
            _x.endDateTime = endDateTime;
            _x.startDateTime = startDateTime;
            _x.theme = theme;
            _x.activities = activities;
            _x.activitiesNextLink = activitiesNextLink;
            _x.displayName = displayName;
            _x.notes = notes;
            return _x;
        }
    }

    private ShiftItem _copy() {
        ShiftItem _x = new ShiftItem();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.endDateTime = endDateTime;
        _x.startDateTime = startDateTime;
        _x.theme = theme;
        _x.activities = activities;
        _x.displayName = displayName;
        _x.notes = notes;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ShiftItem[");
        b.append("endDateTime=");
        b.append(this.endDateTime);
        b.append(", ");
        b.append("startDateTime=");
        b.append(this.startDateTime);
        b.append(", ");
        b.append("theme=");
        b.append(this.theme);
        b.append(", ");
        b.append("activities=");
        b.append(this.activities);
        b.append(", ");
        b.append("displayName=");
        b.append(this.displayName);
        b.append(", ");
        b.append("notes=");
        b.append(this.notes);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
